UI/BrowserModel.py

changeset 15
f6ccc31d6e72
parent 13
1af94a91f439
child 103
59137afca666
--- a/UI/BrowserModel.py	Sat Jan 02 16:15:57 2010 +0000
+++ b/UI/BrowserModel.py	Sat Jan 02 17:09:08 2010 +0000
@@ -954,17 +954,17 @@
     
     def isProjectFile(self):
         """
         Public method to check, if this file is an eric4 project file.
         
-        @return flag indicating an eric4 project file (boolean)
+        @return flag indicating an eric project file (boolean)
         """
-        return self.fileext in ['.e3p', '.e3pz', '.e4p', '.e4pz']
+        return self.fileext in ['.e4p', '.e4pz']
     
     def isMultiProjectFile(self):
         """
         Public method to check, if this file is an eric4 multi project file.
         
-        @return flag indicating an eric4 project file (boolean)
+        @return flag indicating an eric project file (boolean)
         """
         return self.fileext in ['.e4m', '.e4mz']
     
@@ -954,17 +954,17 @@
     def isProjectFile(self):
         """
-        Public method to check, if this file is an eric4 project file.
+        Public method to check, if this file is an eric project file.
         
@@ -954,17 +954,17 @@
     def isMultiProjectFile(self):
         """
-        Public method to check, if this file is an eric4 multi project file.
+        Public method to check, if this file is an eric multi project file.
         

eric ide

mercurial